/* file.h
   $Id: file.h,v 1.5 2001/11/28 00:23:21 elf Exp $
   
   written by Marc Singer
   25 Oct 1996

   This file is part of the project CurVeS.  See the file README for
   more information.

   Copyright (C) 1996 Marc Singer

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   with your Debian GNU/Linux system, in
   /usr/share/common-licenses/GPL, or with the Debian GNU/Linux hello
   source package as the file COPYING. If not, write to the Free
   Software Foundation, Inc., 59 Temple Place -Suite 330, MA
   02111-1307, USA.

*/

#if !defined (__FILE_H__)
#    define   __FILE_H__

/* ----- Includes */

/* ----- Globals */

/* ----- Prototypes */

long file_copy (const char* szFileDst, const char* szFileSrc);
const char* file_edit (const char* szFile);
bool file_guess_binary (const char* szFile);


#endif  /* __FILE_H__ */
